@@ -1,7 +1,7 @@
-import autoarray as aa
 import matplotlib
+from autoarray import conf
 
-backend = aa.conf.instance.visualize.get("figures", "backend", str)
+backend = conf.get_matplotlib_backend()
 matplotlib.use(backend)
 import matplotlib.pyplot as plt
 import matplotlib.cm as cm
@@ -9,22 +9,24 @@ import numpy as np
 import itertools
 from scipy.spatial import Voronoi
 
-from autoarray.plotters import grid_plotters, imaging_plotters, plotter_util
+from autoarray.plotters import imaging_plotters, grid_plotters
+from autoarray.util import plotter_util
 from autoarray.operators.inversion import mappers
 
 
 def image_and_mapper(
     imaging,
     mapper,
-    mask_overlay=None,
+    mask=None,
     positions=None,
-    should_plot_centres=False,
-    should_plot_grid=False,
-    should_plot_border=False,
+    include_centres=False,
+    include_grid=False,
+    include_border=False,
     image_pixels=None,
     source_pixels=None,
-    units="arcsec",
-    kpc_per_arcsec=None,
+    use_scaled_units=True,
+    unit_conversion_factor=None,
+    unit_label="scaled",
     output_path=None,
     output_filename="image_and_mapper",
     output_format="show",
@@ -38,11 +40,12 @@ def image_and_mapper(
 
     imaging_plotters.image(
         imaging=imaging,
-        mask_overlay=mask_overlay,
+        mask=mask,
         positions=positions,
         as_subplot=True,
-        units=units,
-        kpc_per_arcsec=None,
+        use_scaled_units=use_scaled_units,
+        unit_conversion_factor=unit_conversion_factor,
+        unit_label=unit_label,
         xyticksize=16,
         norm="linear",
         norm_min=None,
@@ -60,18 +63,14 @@ def image_and_mapper(
         output_format=output_format,
     )
 
-    image_grid = convert_grid(
-        grid=mapper.grid.geometry.unmasked_grid,
-        units=units,
-        kpc_per_arcsec=kpc_per_arcsec,
-    )
-
     point_colors = itertools.cycle(["y", "r", "k", "g", "m"])
     plot_image_pixels(
-        grid=image_grid, image_pixels=image_pixels, point_colors=point_colors
+        grid=mapper.grid.geometry.unmasked_grid,
+        image_pixels=image_pixels,
+        point_colors=point_colors,
     )
     plot_image_plane_source_pixels(
-        grid=image_grid,
+        grid=mapper.grid.geometry.unmasked_grid,
         mapper=mapper,
         source_pixels=source_pixels,
         point_colors=point_colors,
@@ -81,14 +80,15 @@ def image_and_mapper(
 
     plot_mapper(
         mapper=mapper,
-        should_plot_centres=should_plot_centres,
-        should_plot_grid=should_plot_grid,
-        should_plot_border=should_plot_border,
+        include_centres=include_centres,
+        include_grid=include_grid,
+        include_border=include_border,
         image_pixels=image_pixels,
         source_pixels=source_pixels,
         as_subplot=True,
-        units=units,
-        kpc_per_arcsec=kpc_per_arcsec,
+        unit_label=unit_label,
+        use_scaled_units=use_scaled_units,
+        unit_conversion_factor=unit_conversion_factor,
         figsize=None,
     )
 
@@ -102,14 +102,15 @@ def image_and_mapper(
 
 def plot_mapper(
     mapper,
-    should_plot_centres=False,
-    should_plot_grid=False,
-    should_plot_border=False,
+    include_centres=False,
+    include_grid=False,
+    include_border=False,
     image_pixels=None,
     source_pixels=None,
     as_subplot=False,
-    units="arcsec",
-    kpc_per_arcsec=None,
+    use_scaled_units=True,
+    unit_label="scaled",
+    unit_conversion_factor=None,
     xyticksize=16,
     figsize=(7, 7),
     title="Mapper",
@@ -121,18 +122,19 @@ def plot_mapper(
     output_format="show",
 ):
 
-    if isinstance(mapper, mappers.RectangularMapper):
+    if isinstance(mapper, mappers.MapperRectangular):
 
         rectangular_mapper(
             mapper=mapper,
-            should_plot_centres=should_plot_centres,
-            should_plot_grid=should_plot_grid,
-            should_plot_border=should_plot_border,
+            include_centres=include_centres,
+            include_grid=include_grid,
+            include_border=include_border,
             image_pixels=image_pixels,
             source_pixels=source_pixels,
             as_subplot=as_subplot,
-            units=units,
-            kpc_per_arcsec=kpc_per_arcsec,
+            use_scaled_units=use_scaled_units,
+            unit_label=unit_label,
+            unit_conversion_factor=unit_conversion_factor,
             xyticksize=xyticksize,
             figsize=figsize,
             title=title,
@@ -147,14 +149,15 @@ def plot_mapper(
 
 def rectangular_mapper(
     mapper,
-    should_plot_centres=False,
-    should_plot_grid=False,
-    should_plot_border=False,
+    include_centres=False,
+    include_grid=False,
+    include_border=False,
     image_pixels=None,
     source_pixels=None,
     as_subplot=False,
-    units="arcsec",
-    kpc_per_arcsec=None,
+    use_scaled_units=True,
+    unit_label="scaled",
+    unit_conversion_factor=None,
     xyticksize=16,
     figsize=(7, 7),
     title="Rectangular Mapper",
@@ -168,33 +171,35 @@ def rectangular_mapper(
 
     plotter_util.setup_figure(figsize=figsize, as_subplot=as_subplot)
 
-    set_axis_limits(mapper=mapper, units=units, kpc_per_arcsec=kpc_per_arcsec)
+    grid_plotters.set_axis_limits(
+        axis_limits=mapper.pixelization_grid.extent,
+        grid=None,
+        symmetric_around_centre=False,
+    )
+
+    plotter_util.set_yxticks(array=None, extent=mapper.pixelization_grid.extent, use_scaled_units=use_scaled_units,
+                             unit_conversion_factor=unit_conversion_factor, xticks_manual=None, yticks_manual=None)
+
     plot_rectangular_pixelization_lines(
-        mapper=mapper, units=units, kpc_per_arcsec=kpc_per_arcsec
+        mapper=mapper,
     )
 
     plotter_util.set_title(title=title, titlesize=titlesize)
-    grid_plotters.set_xy_labels(
-        units=units,
-        kpc_per_arcsec=kpc_per_arcsec,
+    plotter_util.set_xy_labels_and_ticksize(
+        unit_label=unit_label,
         xlabelsize=xlabelsize,
         ylabelsize=ylabelsize,
         xyticksize=xyticksize,
     )
 
-    plot_centres(
-        should_plot_centres=should_plot_centres,
-        mapper=mapper,
-        units=units,
-        kpc_per_arcsec=kpc_per_arcsec,
-    )
+    plot_centres(include_centres=include_centres, mapper=mapper)
 
-    plot_plane_grid(
-        should_plot_grid=should_plot_grid,
+    plot_mapper_grid(
+        include_grid=include_grid,
         mapper=mapper,
         as_subplot=True,
-        units=units,
-        kpc_per_arcsec=kpc_per_arcsec,
+        unit_label=unit_label,
+        unit_conversion_factor=unit_conversion_factor,
         pointsize=10,
         xyticksize=xyticksize,
         title=title,
@@ -204,11 +209,11 @@ def rectangular_mapper(
     )
 
     plot_border(
-        should_plot_border=should_plot_border,
+        include_border=include_border,
         mapper=mapper,
         as_subplot=True,
-        units=units,
-        kpc_per_arcsec=kpc_per_arcsec,
+        unit_label=unit_label,
+        unit_conversion_factor=unit_conversion_factor,
         pointsize=30,
         xyticksize=xyticksize,
         title=title,
@@ -217,16 +222,12 @@ def rectangular_mapper(
         ylabelsize=ylabelsize,
     )
 
-    mapper_grid = convert_grid(
-        grid=mapper.grid, units=units, kpc_per_arcsec=kpc_per_arcsec
-    )
-
     point_colors = itertools.cycle(["y", "r", "k", "g", "m"])
     plot_source_plane_image_pixels(
-        grid=mapper_grid, image_pixels=image_pixels, point_colors=point_colors
+        grid=mapper.grid, image_pixels=image_pixels, point_colors=point_colors
     )
     plot_source_plane_source_pixels(
-        grid=mapper_grid,
+        grid=mapper.grid,
         mapper=mapper,
         source_pixels=source_pixels,
         point_colors=point_colors,
@@ -245,14 +246,16 @@ def rectangular_mapper(
 def voronoi_mapper(
     mapper,
     source_pixel_values,
-    should_plot_centres=True,
-    should_plot_grid=True,
-    should_plot_border=False,
+    include_centres=True,
+    lines=None,
+    include_grid=True,
+    include_border=False,
     image_pixels=None,
     source_pixels=None,
     as_subplot=False,
-    units="arcsec",
-    kpc_per_arcsec=None,
+    use_scaled_units=True,
+    unit_label="scaled",
+    unit_conversion_factor=None,
     xyticksize=16,
     figsize=(7, 7),
     title="Rectangular Mapper",
@@ -271,7 +274,14 @@ def voronoi_mapper(
 
     plotter_util.setup_figure(figsize=figsize, as_subplot=as_subplot)
 
-    set_axis_limits(mapper=mapper, units=units, kpc_per_arcsec=kpc_per_arcsec)
+    grid_plotters.set_axis_limits(
+        axis_limits=mapper.pixelization_grid.extent,
+        grid=None,
+        symmetric_around_centre=False,
+    )
+
+    plotter_util.set_yxticks(array=None, extent=mapper.pixelization_grid.extent, use_scaled_units=use_scaled_units,
+                             unit_conversion_factor=unit_conversion_factor, xticks_manual=None, yticks_manual=None)
 
     regions_SP, vertices_SP = voronoi_finite_polygons_2d(mapper.voronoi)
 
@@ -293,27 +303,21 @@ def voronoi_mapper(
         plt.fill(*zip(*polygon), alpha=0.7, facecolor=col, lw=0.0)
 
     plotter_util.set_title(title=title, titlesize=titlesize)
-    grid_plotters.set_xy_labels(
-        units=units,
-        kpc_per_arcsec=kpc_per_arcsec,
+    plotter_util.set_xy_labels_and_ticksize(
+        unit_label=unit_label,
         xlabelsize=xlabelsize,
         ylabelsize=ylabelsize,
         xyticksize=xyticksize,
     )
 
-    plot_centres(
-        should_plot_centres=should_plot_centres,
-        mapper=mapper,
-        units=units,
-        kpc_per_arcsec=kpc_per_arcsec,
-    )
+    plot_centres(include_centres=include_centres, mapper=mapper)
 
-    plot_plane_grid(
-        should_plot_grid=should_plot_grid,
+    plot_mapper_grid(
+        include_grid=include_grid,
         mapper=mapper,
         as_subplot=True,
-        units=units,
-        kpc_per_arcsec=kpc_per_arcsec,
+        unit_label=unit_label,
+        unit_conversion_factor=unit_conversion_factor,
         pointsize=10,
         xyticksize=xyticksize,
         title=title,
@@ -323,11 +327,11 @@ def voronoi_mapper(
     )
 
     plot_border(
-        should_plot_border=should_plot_border,
+        include_border=include_border,
         mapper=mapper,
         as_subplot=True,
-        units=units,
-        kpc_per_arcsec=kpc_per_arcsec,
+        unit_label=unit_label,
+        unit_conversion_factor=unit_conversion_factor,
         pointsize=30,
         xyticksize=xyticksize,
         title=title,
@@ -336,16 +340,14 @@ def voronoi_mapper(
         ylabelsize=ylabelsize,
     )
 
-    mapper_grid = convert_grid(
-        grid=mapper.grid, units=units, kpc_per_arcsec=kpc_per_arcsec
-    )
+    plotter_util.plot_lines(line_lists=lines)
 
     point_colors = itertools.cycle(["y", "r", "k", "g", "m"])
     plot_source_plane_image_pixels(
-        grid=mapper_grid, image_pixels=image_pixels, point_colors=point_colors
+        grid=mapper.grid, image_pixels=image_pixels, point_colors=point_colors
     )
     plot_source_plane_source_pixels(
-        grid=mapper_grid,
+        grid=mapper.grid,
         mapper=mapper,
         source_pixels=source_pixels,
         point_colors=point_colors,
@@ -442,33 +444,20 @@ def voronoi_finite_polygons_2d(vor, radius=None):
     return new_regions, np.asarray(new_vertices)
 
 
-def plot_rectangular_pixelization_lines(mapper, units, kpc_per_arcsec):
+def plot_rectangular_pixelization_lines(
+    mapper,
+):
 
-    if units in "arcsec" or kpc_per_arcsec is None:
-
-        ys = np.linspace(
-            mapper.grid.arc_second_minima[0],
-            mapper.grid.arc_second_maxima[0],
-            mapper.shape_2d[0] + 1,
-        )
-        xs = np.linspace(
-            mapper.grid.arc_second_minima[1],
-            mapper.grid.arc_second_maxima[1],
-            mapper.shape_2d[1] + 1,
-        )
-
-    elif units in "kpc":
-
-        ys = np.linspace(
-            mapper.grid.arc_second_minima[0] * kpc_per_arcsec,
-            mapper.grid.arc_second_maxima[0] * kpc_per_arcsec,
-            mapper.shape_2d[0] + 1,
-        )
-        xs = np.linspace(
-            mapper.grid.arc_second_minima[1] * kpc_per_arcsec,
-            mapper.grid.arc_second_maxima[1] * kpc_per_arcsec,
-            mapper.shape_2d[1] + 1,
-        )
+    ys = np.linspace(
+        mapper.pixelization_grid.scaled_minima[0],
+        mapper.pixelization_grid.scaled_maxima[0],
+        mapper.pixelization_grid.shape_2d[0] + 1,
+    )
+    xs = np.linspace(
+        mapper.pixelization_grid.scaled_minima[1],
+        mapper.pixelization_grid.scaled_maxima[1],
+        mapper.pixelization_grid.shape_2d[1] + 1,
+    )
 
     # grid lines
     for x in xs:
@@ -477,39 +466,6 @@ def plot_rectangular_pixelization_lines(mapper, units, kpc_per_arcsec):
         plt.plot([xs[0], xs[-1]], [y, y], color="black", linestyle="-")
 
 
-def set_axis_limits(mapper, units, kpc_per_arcsec):
-
-    if units in "arcsec" or kpc_per_arcsec is None:
-
-        grid_plotters.set_axis_limits(
-            axis_limits=np.asarray(
-                [
-                    mapper.grid.arc_second_minima[1],
-                    mapper.grid.arc_second_maxima[1],
-                    mapper.grid.arc_second_minima[0],
-                    mapper.grid.arc_second_maxima[0],
-                ]
-            ),
-            grid=None,
-            symmetric_around_centre=False,
-        )
-
-    elif units in "kpc":
-
-        grid_plotters.set_axis_limits(
-            axis_limits=np.asarray(
-                [
-                    mapper.grid.arc_second_minima[1] * kpc_per_arcsec,
-                    mapper.grid.arc_second_maxima[1] * kpc_per_arcsec,
-                    mapper.grid.arc_second_minima[0] * kpc_per_arcsec,
-                    mapper.grid.arc_second_maxima[0] * kpc_per_arcsec,
-                ]
-            ),
-            grid=None,
-            symmetric_around_centre=False,
-        )
-
-
 def set_colorbar(
     cmap, color_values, cb_fraction, cb_pad, cb_tick_values, cb_tick_labels
 ):
@@ -526,27 +482,21 @@ def set_colorbar(
         cb.ax.set_yticklabels(cb_tick_labels)
 
 
-def plot_centres(should_plot_centres, mapper, units, kpc_per_arcsec):
+def plot_centres(include_centres, mapper):
 
-    if should_plot_centres:
+    if include_centres:
 
-        if units in "arcsec" or kpc_per_arcsec is None:
-
-            pixelization_grid = mapper.pixelization_grid
-
-        elif units in "kpc":
-
-            pixelization_grid = mapper.pixelization_grid * kpc_per_arcsec
+        pixelization_grid = mapper.pixelization_grid
 
         plt.scatter(y=pixelization_grid[:, 0], x=pixelization_grid[:, 1], s=3, c="r")
 
 
-def plot_plane_grid(
-    should_plot_grid,
+def plot_mapper_grid(
+    include_grid,
     mapper,
     as_subplot,
-    units,
-    kpc_per_arcsec,
+    unit_label,
+    unit_conversion_factor,
     pointsize,
     xyticksize,
     title,
@@ -555,17 +505,13 @@ def plot_plane_grid(
     ylabelsize,
 ):
 
-    if should_plot_grid:
+    if include_grid:
 
-        grid_units = convert_grid(
-            grid=mapper.grid, units=units, kpc_per_arcsec=kpc_per_arcsec
-        )
-
-        aa.plot.grid(
-            grid=grid_units,
+        grid_plotters.plot_grid(
+            grid=mapper.grid,
             as_subplot=as_subplot,
-            units=units,
-            kpc_per_arcsec=kpc_per_arcsec,
+            unit_label=unit_label,
+            unit_conversion_factor=unit_conversion_factor,
             pointsize=pointsize,
             xyticksize=xyticksize,
             title=title,
@@ -576,11 +522,11 @@ def plot_plane_grid(
 
 
 def plot_border(
-    should_plot_border,
+    include_border,
     mapper,
     as_subplot,
-    units,
-    kpc_per_arcsec,
+    unit_label,
+    unit_conversion_factor,
     pointsize,
     xyticksize,
     title,
@@ -589,18 +535,15 @@ def plot_border(
     ylabelsize,
 ):
 
-    if should_plot_border:
+    if include_border:
 
-        border_arcsec = mapper.grid[mapper.grid.sub_border_pixels]
-        border_units = convert_grid(
-            grid=border_arcsec, units=units, kpc_per_arcsec=kpc_per_arcsec
-        )
+        border = mapper.grid[mapper.grid.mask.regions._sub_border_1d_indexes]
 
-        aa.plot.grid(
-            grid=border_units,
+        grid_plotters.plot_grid(
+            grid=border,
             as_subplot=as_subplot,
-            units=units,
-            kpc_per_arcsec=kpc_per_arcsec,
+            unit_label=unit_label,
+            unit_conversion_factor=unit_conversion_factor,
             pointsize=pointsize,
             pointcolor="y",
             xyticksize=xyticksize,
@@ -635,7 +578,7 @@ def plot_image_plane_source_pixels(grid, mapper, source_pixels, point_colors):
                 plt.scatter(
                     y=np.asarray(
                         grid[
-                            mapper.pixelization_1d_index_for_sub_mask_1d_index[
+                            mapper.all_sub_mask_1d_indexes_for_pixelization_1d_index[
                                 source_pixel
                             ],
                             0,
@@ -643,7 +586,7 @@ def plot_image_plane_source_pixels(grid, mapper, source_pixels, point_colors):
                     ),
                     x=np.asarray(
                         grid[
-                            mapper.pixelization_1d_index_for_sub_mask_1d_index[
+                            mapper.all_sub_mask_1d_indexes_for_pixelization_1d_index[
                                 source_pixel
                             ],
                             1,
@@ -678,7 +621,7 @@ def plot_source_plane_source_pixels(grid, mapper, source_pixels, point_colors):
                 plt.scatter(
                     y=np.asarray(
                         grid[
-                            mapper.pixelization_1d_index_for_sub_mask_1d_index[
+                            mapper.all_sub_mask_1d_indexes_for_pixelization_1d_index[
                                 source_pixel
                             ],
                             0,
@@ -686,7 +629,7 @@ def plot_source_plane_source_pixels(grid, mapper, source_pixels, point_colors):
                     ),
                     x=np.asarray(
                         grid[
-                            mapper.pixelization_1d_index_for_sub_mask_1d_index[
+                            mapper.all_sub_mask_1d_indexes_for_pixelization_1d_index[
                                 source_pixel
                             ],
                             1,
@@ -695,11 +638,3 @@ def plot_source_plane_source_pixels(grid, mapper, source_pixels, point_colors):
                     s=8,
                     color=color,
                 )
-
-
-def convert_grid(grid, units, kpc_per_arcsec):
-
-    if units in "arcsec" or kpc_per_arcsec is None:
-        return grid
-    elif units in "kpc":
-        return grid * kpc_per_arcsec
