@@ -113,6 +113,23 @@ class TestMask:
 
             aa.mask.manual(mask_2d=[False, False, True], pixel_scales=False, sub_size=1)
 
+    def test__is_all_false(self):
+
+        mask = aa.mask.manual(mask_2d=[[False, False], [False, False]])
+
+        assert mask.is_all_false == True
+
+        mask = aa.mask.manual(mask_2d=[[False, False]])
+
+        assert mask.is_all_false == True
+
+        mask = aa.mask.manual(mask_2d=[[False, True], [False, False]])
+
+        assert mask.is_all_false == False
+
+        mask = aa.mask.manual(mask_2d=[[True, True], [False, False]])
+
+        assert mask.is_all_false == False
 
 class TestUnmasked:
     def test__mask_all_unmasked__5x5__input__all_are_false(self):
@@ -175,7 +192,7 @@ class TestCircular:
         mask_via_util = aa.util.mask.mask_2d_circular_from_shape_2d_pixel_scales_and_radius(
             shape_2d=(5, 4),
             pixel_scales=(2.7, 2.7),
-            radius_arcsec=3.5,
+            radius=3.5,
             centre=(0.0, 0.0),
         )
 
@@ -183,7 +200,7 @@ class TestCircular:
             shape_2d=(5, 4),
             pixel_scales=(2.7, 2.7),
             sub_size=1,
-            radius_arcsec=3.5,
+            radius=3.5,
             centre=(0.0, 0.0),
         )
 
@@ -195,7 +212,7 @@ class TestCircular:
         mask_via_util = aa.util.mask.mask_2d_circular_from_shape_2d_pixel_scales_and_radius(
             shape_2d=(5, 4),
             pixel_scales=(2.7, 2.7),
-            radius_arcsec=3.5,
+            radius=3.5,
             centre=(0.0, 0.0),
         )
 
@@ -203,7 +220,7 @@ class TestCircular:
             shape_2d=(5, 4),
             pixel_scales=(2.7, 2.7),
             sub_size=1,
-            radius_arcsec=3.5,
+            radius=3.5,
             centre=(0.0, 0.0),
             invert=True,
         )
@@ -218,8 +235,8 @@ class TestAnnular:
         mask_via_util = aa.util.mask.mask_2d_circular_annular_from_shape_2d_pixel_scales_and_radii(
             shape_2d=(5, 4),
             pixel_scales=(2.7, 2.7),
-            inner_radius_arcsec=0.8,
-            outer_radius_arcsec=3.5,
+            inner_radius=0.8,
+            outer_radius=3.5,
             centre=(0.0, 0.0),
         )
 
@@ -227,8 +244,8 @@ class TestAnnular:
             shape_2d=(5, 4),
             pixel_scales=(2.7, 2.7),
             sub_size=1,
-            inner_radius_arcsec=0.8,
-            outer_radius_arcsec=3.5,
+            inner_radius=0.8,
+            outer_radius=3.5,
             centre=(0.0, 0.0),
         )
 
@@ -240,8 +257,8 @@ class TestAnnular:
         mask_via_util = aa.util.mask.mask_2d_circular_annular_from_shape_2d_pixel_scales_and_radii(
             shape_2d=(5, 4),
             pixel_scales=(2.7, 2.7),
-            inner_radius_arcsec=0.8,
-            outer_radius_arcsec=3.5,
+            inner_radius=0.8,
+            outer_radius=3.5,
             centre=(0.0, 0.0),
         )
 
@@ -249,8 +266,8 @@ class TestAnnular:
             shape_2d=(5, 4),
             pixel_scales=(2.7, 2.7),
             sub_size=1,
-            inner_radius_arcsec=0.8,
-            outer_radius_arcsec=3.5,
+            inner_radius=0.8,
+            outer_radius=3.5,
             centre=(0.0, 0.0),
             invert=True,
         )
@@ -265,9 +282,9 @@ class TestAntiAnnular:
         mask_via_util = aa.util.mask.mask_2d_circular_anti_annular_from_shape_2d_pixel_scales_and_radii(
             shape_2d=(9, 9),
             pixel_scales=(1.2, 1.2),
-            inner_radius_arcsec=0.8,
-            outer_radius_arcsec=2.2,
-            outer_radius_2_arcsec=3.0,
+            inner_radius=0.8,
+            outer_radius=2.2,
+            outer_radius_2_scaled=3.0,
             centre=(0.0, 0.0),
         )
 
@@ -275,9 +292,9 @@ class TestAntiAnnular:
             shape_2d=(9, 9),
             pixel_scales=(1.2, 1.2),
             sub_size=1,
-            inner_radius_arcsec=0.8,
-            outer_radius_arcsec=2.2,
-            outer_radius_2_arcsec=3.0,
+            inner_radius=0.8,
+            outer_radius=2.2,
+            outer_radius_2=3.0,
             centre=(0.0, 0.0),
         )
 
@@ -289,9 +306,9 @@ class TestAntiAnnular:
         mask_via_util = aa.util.mask.mask_2d_circular_anti_annular_from_shape_2d_pixel_scales_and_radii(
             shape_2d=(9, 9),
             pixel_scales=(1.2, 1.2),
-            inner_radius_arcsec=0.8,
-            outer_radius_arcsec=2.2,
-            outer_radius_2_arcsec=3.0,
+            inner_radius=0.8,
+            outer_radius=2.2,
+            outer_radius_2_scaled=3.0,
             centre=(0.0, 0.0),
         )
 
@@ -299,9 +316,9 @@ class TestAntiAnnular:
             shape_2d=(9, 9),
             pixel_scales=(1.2, 1.2),
             sub_size=1,
-            inner_radius_arcsec=0.8,
-            outer_radius_arcsec=2.2,
-            outer_radius_2_arcsec=3.0,
+            inner_radius=0.8,
+            outer_radius=2.2,
+            outer_radius_2=3.0,
             centre=(0.0, 0.0),
             invert=True,
         )
@@ -316,7 +333,7 @@ class TestElliptical:
         mask_via_util = aa.util.mask.mask_2d_elliptical_from_shape_2d_pixel_scales_and_radius(
             shape_2d=(8, 5),
             pixel_scales=(2.7, 2.7),
-            major_axis_radius_arcsec=5.7,
+            major_axis_radius=5.7,
             axis_ratio=0.4,
             phi=40.0,
             centre=(0.0, 0.0),
@@ -326,7 +343,7 @@ class TestElliptical:
             shape_2d=(8, 5),
             pixel_scales=(2.7, 2.7),
             sub_size=1,
-            major_axis_radius_arcsec=5.7,
+            major_axis_radius=5.7,
             axis_ratio=0.4,
             phi=40.0,
             centre=(0.0, 0.0),
@@ -340,7 +357,7 @@ class TestElliptical:
         mask_via_util = aa.util.mask.mask_2d_elliptical_from_shape_2d_pixel_scales_and_radius(
             shape_2d=(8, 5),
             pixel_scales=(2.7, 2.7),
-            major_axis_radius_arcsec=5.7,
+            major_axis_radius=5.7,
             axis_ratio=0.4,
             phi=40.0,
             centre=(0.0, 0.0),
@@ -350,7 +367,7 @@ class TestElliptical:
             shape_2d=(8, 5),
             pixel_scales=(2.7, 2.7),
             sub_size=1,
-            major_axis_radius_arcsec=5.7,
+            major_axis_radius=5.7,
             axis_ratio=0.4,
             phi=40.0,
             centre=(0.0, 0.0),
@@ -367,10 +384,10 @@ class TestEllipiticalAnnular:
         mask_via_util = aa.util.mask.mask_2d_elliptical_annular_from_shape_2d_pixel_scales_and_radius(
             shape_2d=(8, 5),
             pixel_scales=(2.7, 2.7),
-            inner_major_axis_radius_arcsec=2.1,
+            inner_major_axis_radius=2.1,
             inner_axis_ratio=0.6,
             inner_phi=20.0,
-            outer_major_axis_radius_arcsec=5.7,
+            outer_major_axis_radius=5.7,
             outer_axis_ratio=0.4,
             outer_phi=40.0,
             centre=(0.0, 0.0),
@@ -380,10 +397,10 @@ class TestEllipiticalAnnular:
             shape_2d=(8, 5),
             pixel_scales=(2.7, 2.7),
             sub_size=1,
-            inner_major_axis_radius_arcsec=2.1,
+            inner_major_axis_radius=2.1,
             inner_axis_ratio=0.6,
             inner_phi=20.0,
-            outer_major_axis_radius_arcsec=5.7,
+            outer_major_axis_radius=5.7,
             outer_axis_ratio=0.4,
             outer_phi=40.0,
             centre=(0.0, 0.0),
@@ -398,10 +415,10 @@ class TestEllipiticalAnnular:
         mask_via_util = aa.util.mask.mask_2d_elliptical_annular_from_shape_2d_pixel_scales_and_radius(
             shape_2d=(8, 5),
             pixel_scales=(2.7, 2.7),
-            inner_major_axis_radius_arcsec=2.1,
+            inner_major_axis_radius=2.1,
             inner_axis_ratio=0.6,
             inner_phi=20.0,
-            outer_major_axis_radius_arcsec=5.7,
+            outer_major_axis_radius=5.7,
             outer_axis_ratio=0.4,
             outer_phi=40.0,
             centre=(0.0, 0.0),
@@ -411,10 +428,10 @@ class TestEllipiticalAnnular:
             shape_2d=(8, 5),
             pixel_scales=(2.7, 2.7),
             sub_size=1,
-            inner_major_axis_radius_arcsec=2.1,
+            inner_major_axis_radius=2.1,
             inner_axis_ratio=0.6,
             inner_phi=20.0,
-            outer_major_axis_radius_arcsec=5.7,
+            outer_major_axis_radius=5.7,
             outer_axis_ratio=0.4,
             outer_phi=40.0,
             centre=(0.0, 0.0),
@@ -445,7 +462,7 @@ class TestFromAndToFits:
 
         os.makedirs(output_data_dir)
 
-        mask.output_fits(file_path=output_data_dir + "mask.fits")
+        mask.output_to_fits(file_path=output_data_dir + "mask.fits")
 
         mask = msk.Mask.from_fits(
             file_path=output_data_dir + "mask.fits",
@@ -459,6 +476,28 @@ class TestFromAndToFits:
         assert mask.pixel_scales == (1.0, 1.0)
         assert mask.origin == (2.0, 2.0)
 
+    def test__load_from_fits_with_resized_mask_shape(self):
+
+        mask = msk.Mask.from_fits(
+            file_path=test_data_dir + "3x3_ones.fits",
+            hdu=0,
+            sub_size=1,
+            pixel_scales=(1.0, 1.0),
+            resized_mask_shape=(1, 1),
+        )
+
+        assert mask.shape_2d == (1, 1)
+
+        mask = msk.Mask.from_fits(
+            file_path=test_data_dir + "3x3_ones.fits",
+            hdu=0,
+            sub_size=1,
+            pixel_scales=(1.0, 1.0),
+            resized_mask_shape=(5, 5),
+        )
+
+        assert mask.shape_2d == (5, 5)
+
 
 class TestSubQuantities:
     def test__sub_shape_is_shape_times_sub_size(self):
