@@ -2,7 +2,7 @@ import numpy as np
 import pytest
 
 import autoarray as aa
-from test_autoarray.mock.mock_grids import MockIrregularGrid
+from test_autoarray.mock.mock_grids import MockGridIrregular
 
 
 def grid_to_pixel_pixels_via_nearest_neighbour(grid, pixel_centers):
@@ -53,13 +53,12 @@ class TestRectangularMapper:
                 ]
             )
 
-            pixelization_grid = aa.pix_grid.RectangularGrid(grid_1d=np.ones((2,2)), shape_2d=(3,3), pixel_scales=(1.0, 1.0))
-
-            mapper = aa.mappers.RectangularMapper(
-                grid=grid,
-                pixelization_grid=pixelization_grid,
+            pixelization_grid = aa.grid_rectangular(
+                grid_1d=np.ones((2, 2)), shape_2d=(3, 3), pixel_scales=(1.0, 1.0)
             )
 
+            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
                 == np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
@@ -99,13 +98,11 @@ class TestRectangularMapper:
                 ]
             )
 
-            pixelization_grid = aa.pix_grid.RectangularGrid.from_shape_2d_and_grid(shape_2d=(3,3), grid=grid)
-
-            mapper = aa.mappers.RectangularMapper(
-                grid=grid,
-                pixelization_grid=pixelization_grid,
+            pixelization_grid = aa.grid_rectangular.overlay_grid(
+                shape_2d=(3, 3), grid=grid
             )
 
+            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
 
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
@@ -144,13 +141,12 @@ class TestRectangularMapper:
                 ]
             )
 
-            pixelization_grid = aa.pix_grid.RectangularGrid.from_shape_2d_and_grid(shape_2d=(3,3), grid=grid)
-
-            mapper = aa.mappers.RectangularMapper(
-                grid=grid,
-                pixelization_grid=pixelization_grid,
+            pixelization_grid = aa.grid_rectangular.overlay_grid(
+                shape_2d=(3, 3), grid=grid
             )
 
+            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
                 == np.array([0, 4, 2, 4, 4, 4, 6, 4, 8])
@@ -195,13 +191,12 @@ class TestRectangularMapper:
                 ]
             )
 
-            pixelization_grid = aa.pix_grid.RectangularGrid.from_shape_2d_and_grid(shape_2d=(4,3), grid=grid)
-
-            mapper = aa.mappers.RectangularMapper(
-                grid=grid,
-                pixelization_grid=pixelization_grid,
+            pixelization_grid = aa.grid_rectangular.overlay_grid(
+                shape_2d=(4, 3), grid=grid
             )
 
+            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
                 == np.array([0, 1, 2, 3, 8, 11])
@@ -248,13 +243,12 @@ class TestRectangularMapper:
                 ]
             )
 
-            pixelization_grid = aa.pix_grid.RectangularGrid.from_shape_2d_and_grid(shape_2d=(3,4), grid=grid)
-
-            mapper = aa.mappers.RectangularMapper(
-                grid=grid,
-                pixelization_grid=pixelization_grid,
+            pixelization_grid = aa.grid_rectangular.overlay_grid(
+                shape_2d=(3, 4), grid=grid
             )
 
+            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
                 == np.array([0, 1, 2, 6, 9, 11])
@@ -287,13 +281,12 @@ class TestRectangularMapper:
                 [[1.5, -1.5], [1.0, 0.0], [1.0, 0.6], [-1.4, 0.0], [-1.5, 1.5]]
             )
 
-            pixelization_grid = aa.pix_grid.RectangularGrid.from_shape_2d_and_grid(shape_2d=(3,3), grid=grid)
-
-            mapper = aa.mappers.RectangularMapper(
-                grid=grid,
-                pixelization_grid=pixelization_grid,
+            pixelization_grid = aa.grid_rectangular.overlay_grid(
+                shape_2d=(3, 3), grid=grid
             )
 
+            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
                 == np.array([0, 1, 2, 7, 8])
@@ -321,13 +314,12 @@ class TestRectangularMapper:
                 [[1.0, -1.5], [1.0, -0.49], [0.32, -1.5], [0.32, 0.51], [-1.0, 1.5]]
             )
 
-            pixelization_grid = aa.pix_grid.RectangularGrid.from_shape_2d_and_grid(shape_2d=(3,3), grid=grid)
-
-            mapper = aa.mappers.RectangularMapper(
-                grid=grid,
-                pixelization_grid=pixelization_grid,
+            pixelization_grid = aa.grid_rectangular.overlay_grid(
+                shape_2d=(3, 3), grid=grid
             )
 
+            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
                 == np.array([0, 1, 3, 5, 8])
@@ -356,13 +348,12 @@ class TestRectangularMapper:
                 [[1.0, -1.5], [1.0, -0.49], [0.49, -1.5], [-0.6, 0.0], [-1.0, 1.5]]
             )
 
-            pixelization_grid = aa.pix_grid.RectangularGrid.from_shape_2d_and_grid(shape_2d=(4,3), grid=grid)
-
-            mapper = aa.mappers.RectangularMapper(
-                grid=grid,
-                pixelization_grid=pixelization_grid,
+            pixelization_grid = aa.grid_rectangular.overlay_grid(
+                shape_2d=(4, 3), grid=grid
             )
 
+            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
                 == np.array([0, 1, 3, 10, 11])
@@ -393,13 +384,12 @@ class TestRectangularMapper:
                 [[1.0, -1.5], [1.0, -0.49], [0.32, -1.5], [-0.34, 0.49], [-1.0, 1.5]]
             )
 
-            pixelization_grid = aa.pix_grid.RectangularGrid.from_shape_2d_and_grid(shape_2d=(3,4), grid=grid)
-
-            mapper = aa.mappers.RectangularMapper(
-                grid=grid,
-                pixelization_grid=pixelization_grid,
+            pixelization_grid = aa.grid_rectangular.overlay_grid(
+                shape_2d=(3, 4), grid=grid
             )
 
+            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
                 == np.array([0, 1, 4, 10, 11])
@@ -440,13 +430,12 @@ class TestRectangularMapper:
                 ]
             )
 
-            pixelization_grid = aa.pix_grid.RectangularGrid.from_shape_2d_and_grid(shape_2d=(3,3), grid=grid)
-
-            mapper = aa.mappers.RectangularMapper(
-                grid=grid,
-                pixelization_grid=pixelization_grid,
+            pixelization_grid = aa.grid_rectangular.overlay_grid(
+                shape_2d=(3, 3), grid=grid
             )
 
+            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
                 == np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
@@ -486,13 +475,12 @@ class TestRectangularMapper:
                 ]
             )
 
-            pixelization_grid = aa.pix_grid.RectangularGrid.from_shape_2d_and_grid(shape_2d=(3,3), grid=grid)
-
-            mapper = aa.mappers.RectangularMapper(
-                grid=grid,
-                pixelization_grid=pixelization_grid,
+            pixelization_grid = aa.grid_rectangular.overlay_grid(
+                shape_2d=(3, 3), grid=grid
             )
 
+            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
                 == np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
@@ -521,13 +509,12 @@ class TestRectangularMapper:
                 [[3.0, -0.5], [3.0, 0.51], [2.49, -0.5], [1.4, 1.0], [1.0, 2.5]]
             )
 
-            pixelization_grid = aa.pix_grid.RectangularGrid.from_shape_2d_and_grid(shape_2d=(4,3), grid=grid)
-
-            mapper = aa.mappers.RectangularMapper(
-                grid=grid,
-                pixelization_grid=pixelization_grid,
+            pixelization_grid = aa.grid_rectangular.overlay_grid(
+                shape_2d=(4, 3), grid=grid
             )
 
+            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
                 == np.array([0, 1, 3, 10, 11])
@@ -563,13 +550,12 @@ class TestRectangularMapper:
                 ]
             )
 
-            pixelization_grid = aa.pix_grid.RectangularGrid.from_shape_2d_and_grid(shape_2d=(3,3), grid=grid)
-
-            mapper = aa.mappers.RectangularMapper(
-                grid=grid,
-                pixelization_grid=pixelization_grid,
+            pixelization_grid = aa.grid_rectangular.overlay_grid(
+                shape_2d=(3, 3), grid=grid
             )
 
+            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+
             recon_pix = mapper.reconstructed_pixelization_from_solution_vector(
                 solution_vector=np.array([1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0])
             )
@@ -583,13 +569,12 @@ class TestRectangularMapper:
 
         def test__compare_to_imaging_util(self):
 
-            pixelization_grid = aa.pix_grid.RectangularGrid.from_shape_2d_and_grid(shape_2d=(4,3), grid=np.ones((2,2)))
-
-            mapper = aa.mappers.RectangularMapper(
-                grid=None,
-                pixelization_grid=pixelization_grid,
+            pixelization_grid = aa.grid_rectangular.overlay_grid(
+                shape_2d=(4, 3), grid=np.ones((2, 2))
             )
 
+            mapper = aa.mapper(grid=None, pixelization_grid=pixelization_grid)
+
             solution = np.array(
                 [1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 1.0, 2.0, 3.0]
             )
@@ -604,13 +589,12 @@ class TestRectangularMapper:
             assert (recon_pix.in_2d == recon_pix_util).all()
             assert recon_pix.shape_2d == (4, 3)
 
-            pixelization_grid = aa.pix_grid.RectangularGrid.from_shape_2d_and_grid(shape_2d=(3,4), grid=np.ones((2,2)))
-
-            mapper = aa.mappers.RectangularMapper(
-                grid=None,
-                pixelization_grid=pixelization_grid,
+            pixelization_grid = aa.grid_rectangular.overlay_grid(
+                shape_2d=(3, 4), grid=np.ones((2, 2))
             )
 
+            mapper = aa.mapper(grid=None, pixelization_grid=pixelization_grid)
+
             solution = np.array(
                 [1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 1.0, 2.0, 3.0]
             )
@@ -625,6 +609,30 @@ class TestRectangularMapper:
             assert (recon_pix.in_2d == recon_pix_util).all()
             assert recon_pix.shape_2d == (3, 4)
 
+    class TestPixelSignals:
+        def test__pixel_signals__compare_to_mapper_util(self, grid_7x7, image_7x7):
+            pixelization_grid = aa.grid_rectangular.overlay_grid(
+                shape_2d=(3, 3), grid=grid_7x7
+            )
+
+            mapper = aa.mapper(
+                grid=grid_7x7,
+                pixelization_grid=pixelization_grid,
+                hyper_image=image_7x7,
+            )
+
+            pixel_signals = mapper.pixel_signals_from_signal_scale(signal_scale=2.0)
+
+            pixel_signals_util = aa.util.mapper.adaptive_pixel_signals_from_images(
+                pixels=9,
+                signal_scale=2.0,
+                pixelization_1d_index_for_sub_mask_1d_index=mapper.pixelization_1d_index_for_sub_mask_1d_index,
+                mask_1d_index_for_sub_mask_1d_index=grid_7x7.regions._mask_1d_index_for_sub_mask_1d_index,
+                hyper_image=image_7x7,
+            )
+
+            assert (pixel_signals == pixel_signals_util).all()
+
 
 class TestVoronoiMapper:
     class TestSubToPixelizationViaNearestNeighborsForTesting:
@@ -722,15 +730,13 @@ class TestVoronoiMapper:
                 [0, 0, 1, 0, 0, 1, 2, 2, 3]
             )
 
-            pixelization_grid = aa.pix_grid.VoronoiGrid(
+            pixelization_grid = aa.grid_voronoi(
                 grid_1d=pixelization_grid,
-                nearest_irregular_1d_index_for_mask_1d_index=nearest_irregular_1d_index_for_mask_1d_index)
-
-            mapper = aa.mappers.VoronoiMapper(
-                grid=grid_7x7,
-                pixelization_grid=pixelization_grid,
+                nearest_irregular_1d_index_for_mask_1d_index=nearest_irregular_1d_index_for_mask_1d_index,
             )
 
+            mapper = aa.mapper(grid=grid_7x7, pixelization_grid=pixelization_grid)
+
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
                 == sub_to_pix_nearest_neighbour
@@ -746,11 +752,12 @@ class TestVoronoiMapper:
                 [0, 0, 1, 0, 0, 1, 2, 2, 3]
             )
 
-            pixelization_grid = aa.pix_grid.VoronoiGrid(
+            pixelization_grid = aa.grid_voronoi(
                 grid_1d=pixelization_grid,
-                nearest_irregular_1d_index_for_mask_1d_index=nearest_irregular_1d_index_for_mask_1d_index)
+                nearest_irregular_1d_index_for_mask_1d_index=nearest_irregular_1d_index_for_mask_1d_index,
+            )
 
-            mapper = aa.mappers.VoronoiMapper(
+            mapper = aa.mapper(
                 grid=grid_7x7,
                 pixelization_grid=pixelization_grid,
                 hyper_image=image_7x7,
